
import 'package:flutter/rendering.dart';

/// trimGenericParams
///
/// Returns the given class name without generic params
String trimGenericParams(String className) {
  return className.replaceAll(RegExp(r'\<.*\>'), '');
}

Rect _getFrameForRenderObject(RenderObject renderObject) {
  final translation = renderObject.getTransformTo(null).getTranslation();
  return renderObject.paintBounds.shift(Offset(translation.x, translation.y));
}

/// getFrameForBox
///
/// Returns the location Rect (position + size) of the given [RenderBox]
Rect getFrameForBox(RenderBox renderBox) {
  if (!renderBox.hasSize) {
    return Rect.zero;
  }
  return _getFrameForRenderObject(renderBox);
}

/// getFrameForSliver
///
/// Returns the location Rect (position + size) of the given [RenderSliver]
Rect getFrameForSliver(RenderSliver renderSliver) {
  if (renderSliver.geometry == null) {
    return Rect.zero;
  }
  return _getFrameForRenderObject(renderSliver);
}

/// getFrameForViewport
///
/// Returns the location Rect (position + size) of the given [RenderAbstractViewport]
Rect getFrameForViewport(RenderAbstractViewport renderViewport) {
  return _getFrameForRenderObject(renderViewport);
}